# coding: utf-8

"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import in10t_api_client
from in10t_api_client.api.trials_api import TrialsApi  # noqa: E501
from in10t_api_client.rest import ApiException


class TestTrialsApi(unittest.TestCase):
    """TrialsApi unit test stubs"""

    def setUp(self):
        self.api = in10t_api_client.api.trials_api.TrialsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_trial_list(self):
        """Test case for trial_list

        View a list of active trials.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from in10t_api_client.models.access_token import AccessToken
from in10t_api_client.models.as_applied_data import AsAppliedData
from in10t_api_client.models.as_applied_data_item import AsAppliedDataItem
from in10t_api_client.models.harvest_data import HarvestData
from in10t_api_client.models.harvest_data_item import HarvestDataItem
from in10t_api_client.models.planting_data import PlantingData
from in10t_api_client.models.planting_data_item import PlantingDataItem
from in10t_api_client.models.processed_harvest_data import ProcessedHarvestData
from in10t_api_client.models.processed_harvest_data_item import ProcessedHarvestDataItem
from in10t_api_client.models.token_credentials import TokenCredentials



# coding: utf-8

"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HarvestDataItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'objectid': 'int',
        'operation': 'str',
        'crop': 'str',
        'segment': 'int',
        'timestamp': 'str',
        '_yield': 'float',
        'buperac': 'float',
        'moisture': 'float',
        'area': 'float',
        'altitude': 'float',
        'headstatus': 'int',
        'grower': 'str',
        'farm': 'str',
        'field': 'str',
        'speed': 'float',
        'width': 'float',
        'bu': 'float',
        'point': 'str',
        'report_name': 'str',
        'year': 'str',
        'created_at': 'str',
        'updated_at': 'str',
        'deleted': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'objectid': 'objectid',
        'operation': 'operation',
        'crop': 'crop',
        'segment': 'segment',
        'timestamp': 'timestamp',
        '_yield': 'yield',
        'buperac': 'buperac',
        'moisture': 'moisture',
        'area': 'area',
        'altitude': 'altitude',
        'headstatus': 'headstatus',
        'grower': 'grower',
        'farm': 'farm',
        'field': 'field',
        'speed': 'speed',
        'width': 'width',
        'bu': 'bu',
        'point': 'point',
        'report_name': 'report_name',
        'year': 'year',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'deleted': 'deleted'
    }

    def __init__(self, id=None, objectid=None, operation=None, crop=None, segment=None, timestamp=None, _yield=None, buperac=None, moisture=None, area=None, altitude=None, headstatus=None, grower=None, farm=None, field=None, speed=None, width=None, bu=None, point=None, report_name=None, year=None, created_at=None, updated_at=None, deleted=None):  # noqa: E501
        """HarvestDataItem - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._objectid = None
        self._operation = None
        self._crop = None
        self._segment = None
        self._timestamp = None
        self.__yield = None
        self._buperac = None
        self._moisture = None
        self._area = None
        self._altitude = None
        self._headstatus = None
        self._grower = None
        self._farm = None
        self._field = None
        self._speed = None
        self._width = None
        self._bu = None
        self._point = None
        self._report_name = None
        self._year = None
        self._created_at = None
        self._updated_at = None
        self._deleted = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if objectid is not None:
            self.objectid = objectid
        if operation is not None:
            self.operation = operation
        if crop is not None:
            self.crop = crop
        if segment is not None:
            self.segment = segment
        if timestamp is not None:
            self.timestamp = timestamp
        if _yield is not None:
            self._yield = _yield
        if buperac is not None:
            self.buperac = buperac
        if moisture is not None:
            self.moisture = moisture
        if area is not None:
            self.area = area
        if altitude is not None:
            self.altitude = altitude
        if headstatus is not None:
            self.headstatus = headstatus
        if grower is not None:
            self.grower = grower
        if farm is not None:
            self.farm = farm
        if field is not None:
            self.field = field
        if speed is not None:
            self.speed = speed
        if width is not None:
            self.width = width
        if bu is not None:
            self.bu = bu
        if point is not None:
            self.point = point
        if report_name is not None:
            self.report_name = report_name
        if year is not None:
            self.year = year
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if deleted is not None:
            self.deleted = deleted

    @property
    def id(self):
        """Gets the id of this HarvestDataItem.  # noqa: E501


        :return: The id of this HarvestDataItem.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HarvestDataItem.


        :param id: The id of this HarvestDataItem.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def objectid(self):
        """Gets the objectid of this HarvestDataItem.  # noqa: E501


        :return: The objectid of this HarvestDataItem.  # noqa: E501
        :rtype: int
        """
        return self._objectid

    @objectid.setter
    def objectid(self, objectid):
        """Sets the objectid of this HarvestDataItem.


        :param objectid: The objectid of this HarvestDataItem.  # noqa: E501
        :type: int
        """

        self._objectid = objectid

    @property
    def operation(self):
        """Gets the operation of this HarvestDataItem.  # noqa: E501


        :return: The operation of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this HarvestDataItem.


        :param operation: The operation of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if operation is not None and len(operation) > 20:
            raise ValueError("Invalid value for `operation`, length must be less than or equal to `20`")  # noqa: E501

        self._operation = operation

    @property
    def crop(self):
        """Gets the crop of this HarvestDataItem.  # noqa: E501


        :return: The crop of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._crop

    @crop.setter
    def crop(self, crop):
        """Sets the crop of this HarvestDataItem.


        :param crop: The crop of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if crop is not None and len(crop) > 20:
            raise ValueError("Invalid value for `crop`, length must be less than or equal to `20`")  # noqa: E501

        self._crop = crop

    @property
    def segment(self):
        """Gets the segment of this HarvestDataItem.  # noqa: E501


        :return: The segment of this HarvestDataItem.  # noqa: E501
        :rtype: int
        """
        return self._segment

    @segment.setter
    def segment(self, segment):
        """Sets the segment of this HarvestDataItem.


        :param segment: The segment of this HarvestDataItem.  # noqa: E501
        :type: int
        """

        self._segment = segment

    @property
    def timestamp(self):
        """Gets the timestamp of this HarvestDataItem.  # noqa: E501


        :return: The timestamp of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this HarvestDataItem.


        :param timestamp: The timestamp of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if timestamp is not None and len(timestamp) > 20:
            raise ValueError("Invalid value for `timestamp`, length must be less than or equal to `20`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def _yield(self):
        """Gets the _yield of this HarvestDataItem.  # noqa: E501


        :return: The _yield of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self.__yield

    @_yield.setter
    def _yield(self, _yield):
        """Sets the _yield of this HarvestDataItem.


        :param _yield: The _yield of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self.__yield = _yield

    @property
    def buperac(self):
        """Gets the buperac of this HarvestDataItem.  # noqa: E501


        :return: The buperac of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self._buperac

    @buperac.setter
    def buperac(self, buperac):
        """Sets the buperac of this HarvestDataItem.


        :param buperac: The buperac of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self._buperac = buperac

    @property
    def moisture(self):
        """Gets the moisture of this HarvestDataItem.  # noqa: E501


        :return: The moisture of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self._moisture

    @moisture.setter
    def moisture(self, moisture):
        """Sets the moisture of this HarvestDataItem.


        :param moisture: The moisture of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self._moisture = moisture

    @property
    def area(self):
        """Gets the area of this HarvestDataItem.  # noqa: E501


        :return: The area of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self._area

    @area.setter
    def area(self, area):
        """Sets the area of this HarvestDataItem.


        :param area: The area of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self._area = area

    @property
    def altitude(self):
        """Gets the altitude of this HarvestDataItem.  # noqa: E501


        :return: The altitude of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self._altitude

    @altitude.setter
    def altitude(self, altitude):
        """Sets the altitude of this HarvestDataItem.


        :param altitude: The altitude of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self._altitude = altitude

    @property
    def headstatus(self):
        """Gets the headstatus of this HarvestDataItem.  # noqa: E501


        :return: The headstatus of this HarvestDataItem.  # noqa: E501
        :rtype: int
        """
        return self._headstatus

    @headstatus.setter
    def headstatus(self, headstatus):
        """Sets the headstatus of this HarvestDataItem.


        :param headstatus: The headstatus of this HarvestDataItem.  # noqa: E501
        :type: int
        """

        self._headstatus = headstatus

    @property
    def grower(self):
        """Gets the grower of this HarvestDataItem.  # noqa: E501


        :return: The grower of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._grower

    @grower.setter
    def grower(self, grower):
        """Sets the grower of this HarvestDataItem.


        :param grower: The grower of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if grower is not None and len(grower) > 40:
            raise ValueError("Invalid value for `grower`, length must be less than or equal to `40`")  # noqa: E501

        self._grower = grower

    @property
    def farm(self):
        """Gets the farm of this HarvestDataItem.  # noqa: E501


        :return: The farm of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._farm

    @farm.setter
    def farm(self, farm):
        """Sets the farm of this HarvestDataItem.


        :param farm: The farm of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if farm is not None and len(farm) > 40:
            raise ValueError("Invalid value for `farm`, length must be less than or equal to `40`")  # noqa: E501

        self._farm = farm

    @property
    def field(self):
        """Gets the field of this HarvestDataItem.  # noqa: E501


        :return: The field of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this HarvestDataItem.


        :param field: The field of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if field is not None and len(field) > 40:
            raise ValueError("Invalid value for `field`, length must be less than or equal to `40`")  # noqa: E501

        self._field = field

    @property
    def speed(self):
        """Gets the speed of this HarvestDataItem.  # noqa: E501


        :return: The speed of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this HarvestDataItem.


        :param speed: The speed of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self._speed = speed

    @property
    def width(self):
        """Gets the width of this HarvestDataItem.  # noqa: E501


        :return: The width of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this HarvestDataItem.


        :param width: The width of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def bu(self):
        """Gets the bu of this HarvestDataItem.  # noqa: E501


        :return: The bu of this HarvestDataItem.  # noqa: E501
        :rtype: float
        """
        return self._bu

    @bu.setter
    def bu(self, bu):
        """Sets the bu of this HarvestDataItem.


        :param bu: The bu of this HarvestDataItem.  # noqa: E501
        :type: float
        """

        self._bu = bu

    @property
    def point(self):
        """Gets the point of this HarvestDataItem.  # noqa: E501


        :return: The point of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._point

    @point.setter
    def point(self, point):
        """Sets the point of this HarvestDataItem.


        :param point: The point of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if point is not None and len(point) > 120:
            raise ValueError("Invalid value for `point`, length must be less than or equal to `120`")  # noqa: E501

        self._point = point

    @property
    def report_name(self):
        """Gets the report_name of this HarvestDataItem.  # noqa: E501


        :return: The report_name of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._report_name

    @report_name.setter
    def report_name(self, report_name):
        """Sets the report_name of this HarvestDataItem.


        :param report_name: The report_name of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if report_name is not None and len(report_name) > 255:
            raise ValueError("Invalid value for `report_name`, length must be less than or equal to `255`")  # noqa: E501

        self._report_name = report_name

    @property
    def year(self):
        """Gets the year of this HarvestDataItem.  # noqa: E501


        :return: The year of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this HarvestDataItem.


        :param year: The year of this HarvestDataItem.  # noqa: E501
        :type: str
        """
        if year is not None and len(year) > 10:
            raise ValueError("Invalid value for `year`, length must be less than or equal to `10`")  # noqa: E501

        self._year = year

    @property
    def created_at(self):
        """Gets the created_at of this HarvestDataItem.  # noqa: E501


        :return: The created_at of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this HarvestDataItem.


        :param created_at: The created_at of this HarvestDataItem.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this HarvestDataItem.  # noqa: E501


        :return: The updated_at of this HarvestDataItem.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this HarvestDataItem.


        :param updated_at: The updated_at of this HarvestDataItem.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def deleted(self):
        """Gets the deleted of this HarvestDataItem.  # noqa: E501


        :return: The deleted of this HarvestDataItem.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this HarvestDataItem.


        :param deleted: The deleted of this HarvestDataItem.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HarvestDataItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HarvestDataItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import in10t_api_client
from in10t_api_client.models.access_token import AccessToken  # noqa: E501
from in10t_api_client.rest import ApiException


class TestAccessToken(unittest.TestCase):
    """AccessToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccessToken(self):
        """Test AccessToken"""
        # FIXME: construct object with mandatory attributes with example values
        # model = in10t_api_client.models.access_token.AccessToken()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AccessToken(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_token': 'str',
        'expires_in': 'str',
        'token_type': 'str'
    }

    attribute_map = {
        'access_token': 'access_token',
        'expires_in': 'expires_in',
        'token_type': 'token_type'
    }

    def __init__(self, access_token=None, expires_in=None, token_type=None):  # noqa: E501
        """AccessToken - a model defined in Swagger"""  # noqa: E501

        self._access_token = None
        self._expires_in = None
        self._token_type = None
        self.discriminator = None

        if access_token is not None:
            self.access_token = access_token
        if expires_in is not None:
            self.expires_in = expires_in
        if token_type is not None:
            self.token_type = token_type

    @property
    def access_token(self):
        """Gets the access_token of this AccessToken.  # noqa: E501


        :return: The access_token of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this AccessToken.


        :param access_token: The access_token of this AccessToken.  # noqa: E501
        :type: str
        """

        self._access_token = access_token

    @property
    def expires_in(self):
        """Gets the expires_in of this AccessToken.  # noqa: E501


        :return: The expires_in of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this AccessToken.


        :param expires_in: The expires_in of this AccessToken.  # noqa: E501
        :type: str
        """

        self._expires_in = expires_in

    @property
    def token_type(self):
        """Gets the token_type of this AccessToken.  # noqa: E501


        :return: The token_type of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this AccessToken.


        :param token_type: The token_type of this AccessToken.  # noqa: E501
        :type: str
        """

        self._token_type = token_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccessToken, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessToken):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from in10t_api_client.api.data_api import DataApi
from in10t_api_client.api.file_data_api import FileDataApi
from in10t_api_client.api.files_api import FilesApi
from in10t_api_client.api.security_api import SecurityApi
from in10t_api_client.api.shapefile_data_api import ShapefileDataApi
from in10t_api_client.api.trials_api import TrialsApi



# coding: utf-8

"""
    IN10T Client Data API

    IN10T Client Data API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: matt@in10t.ag
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HarvestData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'year': 'str',
        'page': 'int',
        'page_size': 'int',
        'record_count': 'int',
        'total_records': 'int',
        'total_page_count': 'int',
        'data': 'list[HarvestDataItem]'
    }

    attribute_map = {
        'year': 'year',
        'page': 'page',
        'page_size': 'page_size',
        'record_count': 'record_count',
        'total_records': 'total_records',
        'total_page_count': 'total_page_count',
        'data': 'data'
    }

    def __init__(self, year=None, page=None, page_size=None, record_count=None, total_records=None, total_page_count=None, data=None):  # noqa: E501
        """HarvestData - a model defined in Swagger"""  # noqa: E501

        self._year = None
        self._page = None
        self._page_size = None
        self._record_count = None
        self._total_records = None
        self._total_page_count = None
        self._data = None
        self.discriminator = None

        if year is not None:
            self.year = year
        if page is not None:
            self.page = page
        if page_size is not None:
            self.page_size = page_size
        if record_count is not None:
            self.record_count = record_count
        if total_records is not None:
            self.total_records = total_records
        if total_page_count is not None:
            self.total_page_count = total_page_count
        if data is not None:
            self.data = data

    @property
    def year(self):
        """Gets the year of this HarvestData.  # noqa: E501


        :return: The year of this HarvestData.  # noqa: E501
        :rtype: str
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this HarvestData.


        :param year: The year of this HarvestData.  # noqa: E501
        :type: str
        """

        self._year = year

    @property
    def page(self):
        """Gets the page of this HarvestData.  # noqa: E501


        :return: The page of this HarvestData.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this HarvestData.


        :param page: The page of this HarvestData.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def page_size(self):
        """Gets the page_size of this HarvestData.  # noqa: E501


        :return: The page_size of this HarvestData.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this HarvestData.


        :param page_size: The page_size of this HarvestData.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def record_count(self):
        """Gets the record_count of this HarvestData.  # noqa: E501


        :return: The record_count of this HarvestData.  # noqa: E501
        :rtype: int
        """
        return self._record_count

    @record_count.setter
    def record_count(self, record_count):
        """Sets the record_count of this HarvestData.


        :param record_count: The record_count of this HarvestData.  # noqa: E501
        :type: int
        """

        self._record_count = record_count

    @property
    def total_records(self):
        """Gets the total_records of this HarvestData.  # noqa: E501


        :return: The total_records of this HarvestData.  # noqa: E501
        :rtype: int
        """
        return self._total_records

    @total_records.setter
    def total_records(self, total_records):
        """Sets the total_records of this HarvestData.


        :param total_records: The total_records of this HarvestData.  # noqa: E501
        :type: int
        """

        self._total_records = total_records

    @property
    def total_page_count(self):
        """Gets the total_page_count of this HarvestData.  # noqa: E501


        :return: The total_page_count of this HarvestData.  # noqa: E501
        :rtype: int
        """
        return self._total_page_count

    @total_page_count.setter
    def total_page_count(self, total_page_count):
        """Sets the total_page_count of this HarvestData.


        :param total_page_count: The total_page_count of this HarvestData.  # noqa: E501
        :type: int
        """

        self._total_page_count = total_page_count

    @property
    def data(self):
        """Gets the data of this HarvestData.  # noqa: E501


        :return: The data of this HarvestData.  # noqa: E501
        :rtype: list[HarvestDataItem]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this HarvestData.


        :param data: The data of this HarvestData.  # noqa: E501
        :type: list[HarvestDataItem]
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HarvestData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HarvestData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
